==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigRequestsFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageRegistryConfigRequestsFluentImpl<A extends ImageRegistryConfigRequestsFluent<A>> extends BaseFluent<A> implements ImageRegistryConfigRequestsFluent<A>{
  public ImageRegistryConfigRequestsFluentImpl() {
  }
  public ImageRegistryConfigRequestsFluentImpl(ImageRegistryConfigRequests instance) {
    this.withRead(instance.getRead()); 
    this.withWrite(instance.getWrite()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ImageRegistryConfigRequestsLimitsBuilder read;
  private ImageRegistryConfigRequestsLimitsBuilder write;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRead instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigRequestsLimits getRead() {
    return this.read!=null ?this.read.build():null;
  }
  public ImageRegistryConfigRequestsLimits buildRead() {
    return this.read!=null ?this.read.build():null;
  }
  public A withRead(ImageRegistryConfigRequestsLimits read) {
    _visitables.get("read").remove(this.read);
    if (read!=null){ this.read= new ImageRegistryConfigRequestsLimitsBuilder(read); _visitables.get("read").add(this.read);} else { this.read = null; _visitables.get("read").remove(this.read); } return (A) this;
  }
  public Boolean hasRead() {
    return this.read != null;
  }
  public ImageRegistryConfigRequestsFluent.ReadNested<A> withNewRead() {
    return new ImageRegistryConfigRequestsFluentImpl.ReadNestedImpl();
  }
  public ImageRegistryConfigRequestsFluent.ReadNested<A> withNewReadLike(ImageRegistryConfigRequestsLimits item) {
    return new ImageRegistryConfigRequestsFluentImpl.ReadNestedImpl(item);
  }
  public ImageRegistryConfigRequestsFluent.ReadNested<A> editRead() {
    return withNewReadLike(getRead());
  }
  public ImageRegistryConfigRequestsFluent.ReadNested<A> editOrNewRead() {
    return withNewReadLike(getRead() != null ? getRead(): new ImageRegistryConfigRequestsLimitsBuilder().build());
  }
  public ImageRegistryConfigRequestsFluent.ReadNested<A> editOrNewReadLike(ImageRegistryConfigRequestsLimits item) {
    return withNewReadLike(getRead() != null ? getRead(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildWrite instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigRequestsLimits getWrite() {
    return this.write!=null ?this.write.build():null;
  }
  public ImageRegistryConfigRequestsLimits buildWrite() {
    return this.write!=null ?this.write.build():null;
  }
  public A withWrite(ImageRegistryConfigRequestsLimits write) {
    _visitables.get("write").remove(this.write);
    if (write!=null){ this.write= new ImageRegistryConfigRequestsLimitsBuilder(write); _visitables.get("write").add(this.write);} else { this.write = null; _visitables.get("write").remove(this.write); } return (A) this;
  }
  public Boolean hasWrite() {
    return this.write != null;
  }
  public ImageRegistryConfigRequestsFluent.WriteNested<A> withNewWrite() {
    return new ImageRegistryConfigRequestsFluentImpl.WriteNestedImpl();
  }
  public ImageRegistryConfigRequestsFluent.WriteNested<A> withNewWriteLike(ImageRegistryConfigRequestsLimits item) {
    return new ImageRegistryConfigRequestsFluentImpl.WriteNestedImpl(item);
  }
  public ImageRegistryConfigRequestsFluent.WriteNested<A> editWrite() {
    return withNewWriteLike(getWrite());
  }
  public ImageRegistryConfigRequestsFluent.WriteNested<A> editOrNewWrite() {
    return withNewWriteLike(getWrite() != null ? getWrite(): new ImageRegistryConfigRequestsLimitsBuilder().build());
  }
  public ImageRegistryConfigRequestsFluent.WriteNested<A> editOrNewWriteLike(ImageRegistryConfigRequestsLimits item) {
    return withNewWriteLike(getWrite() != null ? getWrite(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigRequestsFluentImpl that = (ImageRegistryConfigRequestsFluentImpl) o;
    if (read != null ? !read.equals(that.read) :that.read != null) return false;
    if (write != null ? !write.equals(that.write) :that.write != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(read,  write,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (read != null) { sb.append("read:"); sb.append(read + ","); }
    if (write != null) { sb.append("write:"); sb.append(write + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ReadNestedImpl<N> extends ImageRegistryConfigRequestsLimitsFluentImpl<ImageRegistryConfigRequestsFluent.ReadNested<N>> implements ImageRegistryConfigRequestsFluent.ReadNested<N>,Nested<N>{
    ReadNestedImpl(ImageRegistryConfigRequestsLimits item) {
      this.builder = new ImageRegistryConfigRequestsLimitsBuilder(this, item);
    }
    ReadNestedImpl() {
      this.builder = new ImageRegistryConfigRequestsLimitsBuilder(this);
    }
    ImageRegistryConfigRequestsLimitsBuilder builder;
    public N and() {
      return (N) ImageRegistryConfigRequestsFluentImpl.this.withRead(builder.build());
    }
    public N endRead() {
      return and();
    }
    
  }
  class WriteNestedImpl<N> extends ImageRegistryConfigRequestsLimitsFluentImpl<ImageRegistryConfigRequestsFluent.WriteNested<N>> implements ImageRegistryConfigRequestsFluent.WriteNested<N>,Nested<N>{
    WriteNestedImpl(ImageRegistryConfigRequestsLimits item) {
      this.builder = new ImageRegistryConfigRequestsLimitsBuilder(this, item);
    }
    WriteNestedImpl() {
      this.builder = new ImageRegistryConfigRequestsLimitsBuilder(this);
    }
    ImageRegistryConfigRequestsLimitsBuilder builder;
    public N and() {
      return (N) ImageRegistryConfigRequestsFluentImpl.this.withWrite(builder.build());
    }
    public N endWrite() {
      return and();
    }
    
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigRequestsFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageRegistryConfigRequestsFluentImpl<A extends ImageRegistryConfigRequestsFluent<A>> extends BaseFluent<A> implements ImageRegistryConfigRequestsFluent<A>{
  public ImageRegistryConfigRequestsFluentImpl() {
  }
  public ImageRegistryConfigRequestsFluentImpl(ImageRegistryConfigRequests instance) {
    if (instance != null) {
      this.withRead(instance.getRead());
      this.withWrite(instance.getWrite());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ImageRegistryConfigRequestsLimitsBuilder read;
  private ImageRegistryConfigRequestsLimitsBuilder write;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRead instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigRequestsLimits getRead() {
    return this.read!=null ?this.read.build():null;
  }
  public ImageRegistryConfigRequestsLimits buildRead() {
    return this.read!=null ?this.read.build():null;
  }
  public A withRead(ImageRegistryConfigRequestsLimits read) {
    _visitables.get("read").remove(this.read);
    if (read!=null){ this.read= new ImageRegistryConfigRequestsLimitsBuilder(read); _visitables.get("read").add(this.read);} else { this.read = null; _visitables.get("read").remove(this.read); } return (A) this;
  }
  public Boolean hasRead() {
    return this.read != null;
  }
  public ImageRegistryConfigRequestsFluentImpl.ReadNested<A> withNewRead() {
    return new ImageRegistryConfigRequestsFluentImpl.ReadNestedImpl();
  }
  public ImageRegistryConfigRequestsFluentImpl.ReadNested<A> withNewReadLike(ImageRegistryConfigRequestsLimits item) {
    return new ImageRegistryConfigRequestsFluentImpl.ReadNestedImpl(item);
  }
  public ImageRegistryConfigRequestsFluentImpl.ReadNested<A> editRead() {
    return withNewReadLike(getRead());
  }
  public ImageRegistryConfigRequestsFluentImpl.ReadNested<A> editOrNewRead() {
    return withNewReadLike(getRead() != null ? getRead(): new ImageRegistryConfigRequestsLimitsBuilder().build());
  }
  public ImageRegistryConfigRequestsFluentImpl.ReadNested<A> editOrNewReadLike(ImageRegistryConfigRequestsLimits item) {
    return withNewReadLike(getRead() != null ? getRead(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildWrite instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigRequestsLimits getWrite() {
    return this.write!=null ?this.write.build():null;
  }
  public ImageRegistryConfigRequestsLimits buildWrite() {
    return this.write!=null ?this.write.build():null;
  }
  public A withWrite(ImageRegistryConfigRequestsLimits write) {
    _visitables.get("write").remove(this.write);
    if (write!=null){ this.write= new ImageRegistryConfigRequestsLimitsBuilder(write); _visitables.get("write").add(this.write);} else { this.write = null; _visitables.get("write").remove(this.write); } return (A) this;
  }
  public Boolean hasWrite() {
    return this.write != null;
  }
  public ImageRegistryConfigRequestsFluentImpl.WriteNested<A> withNewWrite() {
    return new ImageRegistryConfigRequestsFluentImpl.WriteNestedImpl();
  }
  public ImageRegistryConfigRequestsFluentImpl.WriteNested<A> withNewWriteLike(ImageRegistryConfigRequestsLimits item) {
    return new ImageRegistryConfigRequestsFluentImpl.WriteNestedImpl(item);
  }
  public ImageRegistryConfigRequestsFluentImpl.WriteNested<A> editWrite() {
    return withNewWriteLike(getWrite());
  }
  public ImageRegistryConfigRequestsFluentImpl.WriteNested<A> editOrNewWrite() {
    return withNewWriteLike(getWrite() != null ? getWrite(): new ImageRegistryConfigRequestsLimitsBuilder().build());
  }
  public ImageRegistryConfigRequestsFluentImpl.WriteNested<A> editOrNewWriteLike(ImageRegistryConfigRequestsLimits item) {
    return withNewWriteLike(getWrite() != null ? getWrite(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigRequestsFluentImpl that = (ImageRegistryConfigRequestsFluentImpl) o;
    if (!java.util.Objects.equals(read, that.read)) return false;

    if (!java.util.Objects.equals(write, that.write)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(read,  write,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (read != null) { sb.append("read:"); sb.append(read + ","); }
    if (write != null) { sb.append("write:"); sb.append(write + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ReadNestedImpl<N> extends ImageRegistryConfigRequestsLimitsFluentImpl<ImageRegistryConfigRequestsFluentImpl.ReadNested<N>> implements ImageRegistryConfigRequestsFluentImpl.ReadNested<N>,Nested<N>{
    ReadNestedImpl(ImageRegistryConfigRequestsLimits item) {
      this.builder = new ImageRegistryConfigRequestsLimitsBuilder(this, item);
    }
    ReadNestedImpl() {
      this.builder = new ImageRegistryConfigRequestsLimitsBuilder(this);
    }
    ImageRegistryConfigRequestsLimitsBuilder builder;
    public N and() {
      return (N) ImageRegistryConfigRequestsFluentImpl.this.withRead(builder.build());
    }
    public N endRead() {
      return and();
    }
    
  }
  class WriteNestedImpl<N> extends ImageRegistryConfigRequestsLimitsFluentImpl<ImageRegistryConfigRequestsFluentImpl.WriteNested<N>> implements ImageRegistryConfigRequestsFluentImpl.WriteNested<N>,Nested<N>{
    WriteNestedImpl(ImageRegistryConfigRequestsLimits item) {
      this.builder = new ImageRegistryConfigRequestsLimitsBuilder(this, item);
    }
    WriteNestedImpl() {
      this.builder = new ImageRegistryConfigRequestsLimitsBuilder(this);
    }
    ImageRegistryConfigRequestsLimitsBuilder builder;
    public N and() {
      return (N) ImageRegistryConfigRequestsFluentImpl.this.withWrite(builder.build());
    }
    public N endWrite() {
      return and();
    }
    
  }
  
}
